Known Issues — Dugong 2.1 documentation

### Navigation

- index
- next |
- previous |
- Dugong 2.1 documentation »

# Known Issues

- When sending requests with a `Range` header, Dugong may be unable to parse the server response. This happens if the server sends `multipart/byteranges` data without a `Content-Length` header. This is allowed by RFC 2616, because the content length is implicit in the multipart body, but Dugong does not yet support parsing the body.

### Navigation

- index
- next |
- previous |
- Dugong 2.1 documentation »